--- sip/_QOpenGLFunctions_4_1_Core/qopenglfunctions_4_1_core.sip	2018-02-27 05:44:06.000000000 -0500
+++ sip/_QOpenGLFunctions_4_1_Core/qopenglfunctions_4_1_core_patched.sip	2018-03-01 14:02:03.000000000 -0500
@@ -986,6 +986,97 @@
     void glClearDepthf(GLfloat dd);
     void glDepthRangef(GLfloat n, GLfloat f);
     void glReleaseShaderCompiler();
+
+    /* Implementation of glReadPixels
+     * Jayson Kempinger (jkempinger@decisionvis.com)
+     * DecisionVis, LLC (https://www.decisionvis.com)
+     * Copyright 2018 DecisionVis, LLC; released under the MIT license
+    */
+    SIP_PYOBJECT glReadPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type) /TypeHint="Tuple[GL type, ...]"/;
+%MethodCode
+        short components;
+        switch (a4) {
+            case GL_BGR:
+            case GL_RGB: {
+                components = 3;
+                break;
+            }
+            case GL_BGRA:
+            case GL_RGBA: {
+                components = 4;
+                break;
+            }
+            case GL_RED:
+            case GL_GREEN:
+            case GL_BLUE:
+            case GL_ALPHA:
+            case GL_DEPTH_COMPONENT:
+            case GL_STENCIL_INDEX:
+            case GL_DEPTH_STENCIL: {
+                components = 1;
+                break;
+            }
+            default: {
+                components = 0;
+                break;
+            }
+        }
+        unsigned int length = components * a2 * a3;
+
+        switch (a5) {
+            case GL_FLOAT: {
+                GLfloat *data = new GLfloat[length];
+                sipCpp->glReadPixels(a0, a1, a2, a3, a4, a5, data);
+                sipRes = qpyopengl_from_GLfloat(&sipIsErr, data, length);
+                delete [] data;
+                break;
+            }
+            case GL_INT: {
+                GLint *data = new GLint[length];
+                sipCpp->glReadPixels(a0, a1, a2, a3, a4, a5, data);
+                sipRes = qpyopengl_from_GLint(&sipIsErr, data, length);
+                delete [] data;
+                break;
+            }
+            case GL_UNSIGNED_INT:
+            case GL_UNSIGNED_INT_8_8_8_8:
+            case GL_UNSIGNED_INT_8_8_8_8_REV:
+            case GL_UNSIGNED_INT_10_10_10_2:
+            case GL_UNSIGNED_INT_2_10_10_10_REV:
+            case GL_UNSIGNED_INT_24_8:
+            case GL_UNSIGNED_INT_10F_11F_11F_REV:
+            case GL_UNSIGNED_INT_5_9_9_9_REV: {
+                GLuint *data = new GLuint[length];
+                sipCpp->glReadPixels(a0, a1, a2, a3, a4, a5, data);
+                sipRes = qpyopengl_from_GLuint(&sipIsErr, data, length);
+                delete [] data;
+                break;
+            }
+            case GL_SHORT:
+            case GL_UNSIGNED_SHORT:
+            case GL_UNSIGNED_SHORT_5_6_5:
+            case GL_UNSIGNED_SHORT_5_6_5_REV:
+            case GL_UNSIGNED_SHORT_4_4_4_4:
+            case GL_UNSIGNED_SHORT_4_4_4_4_REV:
+            case GL_UNSIGNED_SHORT_5_5_5_1:
+            case GL_UNSIGNED_SHORT_1_5_5_5_REV:
+            case GL_BYTE:
+            case GL_UNSIGNED_BYTE:
+            case GL_UNSIGNED_BYTE_3_3_2:
+            case GL_UNSIGNED_BYTE_2_3_3_REV:
+            case GL_HALF_FLOAT:
+            case GL_FLOAT_32_UNSIGNED_INT_24_8_REV:
+            default: {
+                PyErr_SetString(PyExc_NotImplementedError, "Data type has not been implemented");
+                break;
+            }
+        }
+
+        if (sipIsErr) {
+            PyErr_SetString(PyExc_BufferError, "Unable to read data");
+        }
+%End
+
 };
 
 %End
